Form

Struct Form 

pub struct Form { /* private fields */ }
Available on crate features client and multipart only.
A multipart/form-data request body.

A Form is a series of Parts, it can be sent through RequestBuilder::multipart, which will set the Content-Type header (with the generated boundary) and the body automatically.

Implementations

Source

impl Form

pub fn new() -> Self

Create an empty Form with a randomly generated boundary.

pub fn boundary(&self) -> &str

Get the boundary that this form will use.

pub fn text<N, V>(self, name: N, value: V) -> Self
where N: Into<Cow<'static, str>>, V: Into<Cow<'static, str>>,

Add a text field to the form.

This is a shortcut for Form::part with Part::text.

pub fn part<N>(self, name: N, part: Part) -> Self
where N: Into<Cow<'static, str>>,

Add a Part to the form with the given field name.

pub async fn file<N, P>(self, name: N, path: P) -> Result<Self>
where N: Into<Cow<'static, str>>, P: AsRef<Path>,

Add a file field to the form, the file will be read and streamed lazily.

The Content-Type is guessed from the file extension, and the filename is taken from the path if it is not overridden. This is a shortcut for Form::part with Part::file.