#[non_exhaustive]pub enum ExtractBodyError {
Generic(GenericRejectionError),
String(Utf8Error),
Json(Error),
Form(Error),
}Available on crate feature
server only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Generic(GenericRejectionError)
Generic extracting errors when pulling Body or checking
Content-Type of request
String(Utf8Error)
Json(Error)
Available on crate feature
json only.The Body cannot be extracted as a json object
Form(Error)
Available on crate feature
form only.The Body cannot be extracted as a form object