pub struct Incoming { /* private fields */ }Expand description
A stream of Bytes, used when receiving bodies from the network.
Note that Users should not instantiate this struct directly. When working with the hyper client,
Incoming is returned to you in responses. Similarly, when operating with the hyper server,
it is provided within requests.
Examples
ⓘ
async fn echo(
req: Request<hyper::body::Incoming>,
) -> Result<Response<BoxBody<Bytes, hyper::Error>>, hyper::Error> {
//Here, you can process `Incoming`
}Trait Implementations
sourceimpl Body for Incoming
impl Body for Incoming
sourcefn poll_frame(
self: Pin<&mut Incoming>,
cx: &mut Context<'_>
) -> Poll<Option<Result<Frame<<Incoming as Body>::Data>, <Incoming as Body>::Error>>>
fn poll_frame( self: Pin<&mut Incoming>, cx: &mut Context<'_> ) -> Poll<Option<Result<Frame<<Incoming as Body>::Data>, <Incoming as Body>::Error>>>
Attempt to pull out the next data buffer of this stream.
sourcefn is_end_stream(&self) -> bool
fn is_end_stream(&self) -> bool
Returns
true when the end of stream has been reached. Read moresourceimpl<S: Sync> FromRequest<S> for Incoming
impl<S: Sync> FromRequest<S> for Incoming
sourceimpl<I, F, S, T> Service<HttpContext, Incoming> for FromFn<I, F, S, T>where
I: Service<HttpContext, Incoming, Response = Response, Error = Infallible> + Clone + Send + Sync + 'static,
F: for<'r> MiddlewareHandlerFromFn<'r, T, S> + Clone + Sync,
S: Clone + Sync,
impl<I, F, S, T> Service<HttpContext, Incoming> for FromFn<I, F, S, T>where
I: Service<HttpContext, Incoming, Response = Response, Error = Infallible> + Clone + Send + Sync + 'static,
F: for<'r> MiddlewareHandlerFromFn<'r, T, S> + Clone + Sync,
S: Clone + Sync,
sourceimpl<H, S, T> Service<HttpContext, Incoming> for HandlerService<H, S, T>
impl<H, S, T> Service<HttpContext, Incoming> for HandlerService<H, S, T>
sourceimpl<I, F, S, T> Service<HttpContext, Incoming> for MapResponse<I, F, S, T>where
I: Service<HttpContext, Incoming, Response = Response, Error = Infallible> + Clone + Send + Sync + 'static,
F: for<'r> MiddlewareHandlerMapResponse<'r, T, S> + Clone + Sync,
S: Clone + Sync,
impl<I, F, S, T> Service<HttpContext, Incoming> for MapResponse<I, F, S, T>where
I: Service<HttpContext, Incoming, Response = Response, Error = Infallible> + Clone + Send + Sync + 'static,
F: for<'r> MiddlewareHandlerMapResponse<'r, T, S> + Clone + Sync,
S: Clone + Sync,